pub enum Tailoring {
Cldr(Locale),
Ducet,
}Expand description
This enum provides for a choice of which collation tailoring (or table of character weights) to
use. With the CLDR table, there is a further choice of locale. (The Root locale represents the
table in its unmodified form.)
Variants
Cldr(Locale)
The table associated with the CLDR root collation order, and locale tailorings based thereon (recommended)
Ducet
The default table for the Unicode Collation Algorithm