pub enum Locale {
ArabicScript,
ArabicInterleaved,
Root,
}Expand description
This enum provides for a choice of which locale to use with the CLDR table of character weights.
The default, Root, represents the CLDR root collation order. At the moment, there are only two
other choices: ArabicScript and ArabicInterleaved. But the list should grow over time.
Variants
ArabicScript
This locale defines a tailoring in which the Arabic script sorts before the Latin script. No more granular adjustments have been made.
ArabicInterleaved
This locale defines a tailoring in which Arabic-script characters are interleaved with Latin-script characters, so that alif sorts between A and B, bā’ between B and C, etc.
Root
The CLDR root collation order